﻿

// Pomocná funkce pro vytvoření pole s čísly
function buildArray(min, max) {
    var array = [];
    for (var i = min; i <= max; i++) {
        array.push(i);
    }
    return array;
}


/**
* forEach
*/
function executeExample0() {
    var myArray = buildArray(10, 15);

    myArray
        .forEach(function (value, index) {
            console.log((index + 1) + ". hodnota:", value);
        });
    
}


/**
* indexOf
*/
function executeExample1() {
    var myArray = buildArray(10, 200);

    console.log("Pozice čísla 150:", myArray.indexOf(150));
    console.log("Pozice čísla 3:", myArray.indexOf(3));

}



/**
* map
*/
function executeExample2() {
    var myArray = buildArray(10, 20);
    var mappedArray = myArray.map(function (value, index) {
        return value / 2;
    });

    console.log("Originální pole:", myArray);
    console.log("Namapované pole:", mappedArray);

}



/**
* filter
*/
function executeExample3() {
    var myArray = buildArray(10, 20);
    var filteredArray = myArray.filter(function (value, index) {
        return value % 3 == 0;
    });

    console.log("Originální pole:", myArray);
    console.log("Čísla z pole dělitelná 3:", filteredArray);

}



/**
* every
*/
function executeExample4() {
    var myArray = buildArray(100, 200);
    var areLarge = myArray.every(function (value, index) {
        return value > 99;
    });

    var arePowerOf2 = [2, 4, 8, 6, 16].every(function (value, index) {
        return (value & (value - 1)) == 0;
    });

    console.log("Originální pole:", myArray);
    console.log("Jsou všechna čísla velká:", areLarge);
    console.log("Jsou všechna mocninou 2:", arePowerOf2);

}




/**
* some
*/
function executeExample5() {
    var myArray = buildArray(100, 200);
    var isAnyDivisible8 = myArray.some(function (value, index) {
        return value % 8 == 0;
    });


    console.log("Je v poli číslo dělitelné 8:", isAnyDivisible8);

}





/**
* reduce
*/
function executeExample6() {
    var myArray = buildArray(1, 4);
    var sum = myArray
        .reduce(function (prevValue, curValue, index) {
            return prevValue - curValue;
        });

    
    console.log("Rozdíl čísel 1 až 4:", sum);

}



/**
* reduceRight
*/
function executeExample7() {
    var myArray = buildArray(1, 4);
    var sum = myArray
        .reduceRight(function (prevValue, curValue, index) {
            return prevValue - curValue;
        });


    console.log("Rozdíl čísel 4 až 1:", sum);

}





/**
* Typed arrays
* https://developer.mozilla.org/en-US/docs/Web/JavaScript/Typed_arrays
*/
function executeExample8() {

    // Paměť s 4 * 8 byte (little endian)
    var buffer = new ArrayBuffer(4);

    // Náhled na paměť jako na pole byte-ů
    var byteArray = new Uint8Array(buffer);
    byteArray[0] = 0;
    byteArray[1] = 1;
    byteArray[2] = 0;
    byteArray[3] = 0;
    
    // Náhled paměť, jako a polee int-ů
    var intArray = new Uint32Array(buffer);

    console.log("Datová velikost bufferu:", buffer.byteLength, "byte");
    console.log("Délka pole 'byteArray':", byteArray.length);
    console.log("Datová velikost pole 'byteArray':", byteArray.byteLength);
    console.log("Délka pole 'intArray':", intArray.length);
    console.log("Datová velikost pole 'intArray':", intArray.byteLength);

    console.log("1. hodnota v poli 'intArray':", intArray[0], "(00000000 00000001 00000000 00000000)");

}

